diff mcabber/src/jab_iq.c @ 977:5b01de4ac5e1

Cosmetic changes
author Alexis Hildebrandt <afh [at] 2drop [dot] net>
date Tue, 10 Oct 2006 20:15:06 +0200
parents 1bdf0f1b16c0
children c89e7993c4d9
line wrap: on
line diff
--- a/mcabber/src/jab_iq.c	Tue Oct 10 19:43:32 2006 +0200
+++ b/mcabber/src/jab_iq.c	Tue Oct 10 20:15:06 2006 +0200
@@ -209,8 +209,9 @@
     if (!name)
       name = cleanalias;
 
-    // Tricky... :-\  My guess is that if there is no '@', this is an agent
-    if (strchr(cleanalias, '@'))
+    // Tricky... :-\  My guess is that if there is no JID_DOMAIN_SEPARATOR,
+    // this is an agent.
+    if (strchr(cleanalias, JID_DOMAIN_SEPARATOR))
       roster_type = ROSTER_TYPE_USER;
     else
       roster_type = ROSTER_TYPE_AGENT;
@@ -253,7 +254,7 @@
   scr_LogPrint(LPRINT_LOGNORM, "%s", buf);
 
   // bjid should now really be the "bare JID", let's strip the resource
-  p = strchr(bjid, '/');
+  p = strchr(bjid, JID_RESOURCE_SEPARATOR);
   if (p) *p = '\0';
 
   scr_WriteIncomingMessage(bjid, buf, 0, HBB_PREFIX_INFO);
@@ -329,7 +330,7 @@
   scr_LogPrint(LPRINT_LOGNORM, "%s", buf);
 
   // bjid should now really be the "bare JID", let's strip the resource
-  p = strchr(bjid, '/');
+  p = strchr(bjid, JID_RESOURCE_SEPARATOR);
   if (p) *p = '\0';
 
   scr_WriteIncomingMessage(bjid, buf, 0, HBB_PREFIX_INFO);